#!/usr/bin/env bash
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

set -e

echo "Install Substrait Consumer Test Suite";

git clone https://github.com/substrait-io/consumer-testing.git
cd consumer-testing
# avoid installing pyarrow
grep -v 'pyarrow\|arrow-nightlies' requirements.txt > requirements-no-arrow.txt
pip install -r requirements-no-arrow.txt

pip install -r requirements-build.txt
# setup substrait-java
git submodule init
git submodule update --init
./build-and-copy-isthmus-shadow-jar.sh
# install substrait_consumer library
python setup.py install
